<!-- omit from toc -->
# Camb AI API Wrapper

[![PyPI version](https://badge.fury.io/py/cambai.svg)](https://badge.fury.io/py/cambai)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/cambai)

This is a Python wrapper for the [Camb.ai](https://camb.ai) API. It is designed to make it easy to interact with the API from Python.

> [!IMPORTANT]
> This library is still in active development.
> There will be some fixes and improvements to be made.

<!-- omit from toc -->
## Index

- [Installation](#installation)
- [Usage](#usage)

## Installation

To install the CambAI API Wrapper, you can use `pip` to install:

```bash
# Install from PyPI
pip install cambai
```

## Usage

Checkout the '[**examples**](https://github.com/cr2007/cambai-python/tree/master/examples)' directory for examples on how to use the CambAI API Wrapper.
